==> asset.visuretech.com_v5.1.zip: resources/lang/sr-CS/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'Korisnik je prihvatio stavku',
    'acceptance_asset_declined' => 'Korisnik je odbio stavku',
    'a_user_canceled' => 'Korisnik je otkazao zahtev za stavke na Web lokaciji',
    'a_user_requested' => 'Korisnik je zatražio stavke na Web lokaciji',
    'accessory_name' => 'Naziv dodatne opreme, pribora:',
    'additional_notes' => 'Dodatne napomene:',
    'admin_has_created' => 'Administrator je kreirao nalog za vas na na :web vebsajtu.',
    'asset' => 'Imovina:',
    'asset_name' => 'Naziv imovine:',
    'asset_requested' => 'Traženo sredstvo',
    'asset_tag' => 'Oznaka imovine',
    'assigned_to' => 'Dodijeljena',
    'best_regards' => 'Srdačan pozdrav',
    'canceled' => 'Otkazano:',
    'checkin_date' => 'Checkin Date:',
    'checkout_date' => 'Checkout Date:',
    'click_to_confirm' => 'Kliknite na sljedeći link kako biste potvrdili svoj :web nalog:',
    'click_on_the_link_accessory' => 'Kliknite na link pri dnu da biste potvrdili da ste primili dodatnu opremu.',
    'click_on_the_link_asset' => 'Kliknite na link pri dnu da biste potvrdili da ste primili resurs, imovinu.',
    'Confirm_Asset_Checkin' => 'Potvrda razduženja imovine',
    'Confirm_Accessory_Checkin' => 'Potvrda razduženja opreme',
    'Confirm_accessory_delivery' => 'Potvrda dostave opreme',
    'Confirm_license_delivery' => 'Potvrda dostave licence',
    'Confirm_asset_delivery' => 'Potvrda dostave imovine',
    'Confirm_consumable_delivery' => 'Potvrda isporuke potrošnog materijala',
    'current_QTY' => 'Trenutna QTY',
    'Days' => 'Dani',
    'days' => 'Dana',
    'expecting_checkin_date' => 'Expected Checkin Date:',
    'expires' => 'Ističe',
    'Expiring_Assets_Report' => 'Expiring Assets Report.',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report.',
    'hello' => 'Zdravo',
    'hi' => 'Zdravo',
    'i_have_read' => 'Pročitao sam i prihvatam uvete korištenja i primio sam ovu stavku.',
    'item' => 'Artikal:',
    'Item_Request_Canceled' => 'Zahtev za stavku je otkazan',
    'Item_Requested' => 'Zahtevana stavka',
    'link_to_update_password' => 'Kliknite na sledeću vezu kako biste obnovili svoju :web lozinku:',
    'login_first_admin' => 'Prijavite se u vašu novu Snipe-IT instalaciju koristeći kredencijale ispod:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Izveštaj o niskim zalihama',
    'inventory_report' => 'Izveštaj o zalihama',
    'min_QTY' => 'Min Kol',
    'name' => 'Naziv',
    'new_item_checked' => 'Nova stavka je proverena pod vašim imenom, detalji su u nastavku.',
    'password' => 'Lozinka:',
    'password_reset' => 'Ponovno postavljanje lozinke',

    'read_the_terms' => 'Pročitajte uslove upotrebe u nastavku.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read
                         and agree to the terms of use, and have received the asset.',
    'requested' => 'Traženi:',
    'reset_link' => 'Link za resetovanje lozinke',
    'reset_password' => 'Kliknite ovde da biste poništili lozinku:',
    'serial' => 'Serijski broj',
    'supplier' => 'Dobavljač',
    'tag' => 'Oznaka',
    'test_email' => 'Isprobajte e-poštu od Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'low_inventory_alert' => 'Postoji :count artikla ispod minimalne zalihe ili će uskoro biti nizak. |Postoje :count artikla koji su ispod minimalne zalihe ili će uskoro biti.',
    'assets_warrantee_alert' => 'Postoji :stanje licenci koja/e ističe u narednih :treshold dana.|Postoje :count licenci koje ističu u narednih :treshold dana.',
    'license_expiring_alert' => 'Postoji :count licenci koja/e ističe u narednih treshold dana.|Postoje :count licencei koje ističu u narednih :treshold dana.',
    'to_reset' => 'Da biste resetovali svoju :web lozinku, ispunite ovaj obrazac:',
    'type' => 'Tip',
    'upcoming-audits' => 'Ima :count imovina kojoj je vreme za popis za :threshold dana.|Ima :count imovine kojoj je vreme za popis za :threshold dana.',
    'user' => 'Korisnik',
    'username' => 'Korisničko ime',
    'welcome' => 'Dobrodošli :name',
    'welcome_to' => 'Dobrodošli na :web!',
    'your_credentials' => 'Vaši Snipe-IT kredencijali',
    'Accessory_Checkin_Notification' => 'Oprema razdužena',
    'Asset_Checkin_Notification' => 'Imovina razdužena',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'Licenca razdužena',
    'Expected_Checkin_Report' => 'Izveštaj o očekivanoj proveri imovine',
    'Expected_Checkin_Notification' => 'Izveštaj o očekivanoj proveri imovine',
    'Expected_Checkin_Date' => 'Imovina koja vam je odjavljena treba da bude ponovo prijavljena :date',
    'your_assets' => 'Pregledaj svoju imovinu',
    'rights_reserved' => 'Sva prava zadržana.',
];

==> asset.visuretech.com-8.1.zip: resources/lang/sr-CS/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Oprema razdužena',
    'Accessory_Checkout_Notification' => 'Oprema je zadužena',
    'Asset_Checkin_Notification' => 'Imovina razdužena',
    'Asset_Checkout_Notification' => 'Zadužena imovina',
    'Confirm_Accessory_Checkin' => 'Potvrda razduženja opreme',
    'Confirm_Asset_Checkin' => 'Potvrda razduženja imovine',
    'Confirm_accessory_delivery' => 'Potvrda dostave opreme',
    'Confirm_asset_delivery' => 'Potvrda dostave imovine',
    'Confirm_consumable_delivery' => 'Potvrda isporuke potrošnog materijala',
    'Confirm_license_delivery' => 'Potvrda dostave licence',
    'Consumable_checkout_notification' => 'Potrošni materijal je zadužen',
    'Days' => 'Dani',
    'Expected_Checkin_Date' => 'Imovina koja vam je odjavljena treba da bude ponovo prijavljena :date',
    'Expected_Checkin_Notification' => 'Izveštaj o očekivanoj proveri imovine',
    'Expected_Checkin_Report' => 'Izveštaj o očekivanoj proveri imovine',
    'Expiring_Assets_Report' => 'Expiring Assets Report.',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report.',
    'Item_Request_Canceled' => 'Zahtev za stavku je otkazan',
    'Item_Requested' => 'Zahtevana stavka',
    'License_Checkin_Notification' => 'Licenca razdužena',
    'License_Checkout_Notification' => 'Licenca je zadužena',
    'license_for'   => 'Licenca za',
    'Low_Inventory_Report' => 'Izveštaj o niskim zalihama',
    'a_user_canceled' => 'Korisnik je otkazao zahtev za stavke na Web lokaciji',
    'a_user_requested' => 'Korisnik je zatražio stavke na Web lokaciji',
    'acceptance_asset_accepted_to_user' => 'Prihvatili ste stavku koja vam je dodeljena od :site_name',
    'acceptance_asset_accepted' => 'Korisnik je prihvatio stavku',
    'acceptance_asset_declined' => 'Korisnik je odbio stavku',
    'send_pdf_copy' => 'Pošalji kopiju ove prihvatnice na adresu moje e-pošte',
    'accessory_name' => 'Naziv pribora',
    'additional_notes' => 'Dodatne napomene',
    'admin_has_created' => 'Administrator je kreirao nalog za vas na na :web vebsajtu.',
    'asset' => 'Imovina',
    'asset_name' => 'Naziv imovine',
    'asset_requested' => 'Traženo sredstvo',
    'asset_tag' => 'Oznaka imovine',
    'assets_warrantee_alert' => 'Postoji :stanje licenci koja/e ističe u narednih :treshold dana.|Postoje :count licenci koje ističu u narednih :treshold dana.',
    'assigned_to' => 'Dodijeljena',
    'best_regards' => 'Srdačan pozdrav',
    'canceled' => 'Otkazano',
    'checkin_date' => 'Datum razduženja',
    'checkout_date' => 'Datum zaduženja',
    'checkedout_from' => 'Zaduženo iz',
    'checkedin_from'  => 'Razduženo od',
    'checked_into' => 'Razduženo u',
    'click_on_the_link_accessory' => 'Kliknite na link pri dnu da biste potvrdili da ste primili dodatnu opremu.',
    'click_on_the_link_asset' => 'Kliknite na link pri dnu da biste potvrdili da ste primili resurs, imovinu.',
    'click_to_confirm' => 'Kliknite na sljedeći link kako biste potvrdili svoj :web nalog:',
    'current_QTY' => 'Trenutna QTY',
    'days' => 'Dana',
    'expecting_checkin_date' => 'Očekivani datum razduženja',
    'expires' => 'Ističe',
    'following_accepted' => 'Sledeće je prihvaćeno',
    'following_declined' => 'Sledeće je odbijeno',
    'hello' => 'Zdravo',
    'hi' => 'Zdravo',
    'i_have_read' => 'Pročitao sam i prihvatam uvete korištenja i primio sam ovu stavku.',
    'initiated_accepted' => 'Zaduženje koje ste vi pokrenuli je prihvaćeno',
    'initiated_declined' => 'Zaduženje koje ste vi pokrenuli je odbijeno',
    'inventory_report' => 'Izveštaj o zalihama',
    'item' => 'Stavka',
    'item_checked_reminder' => 'Ovo je podsetnik da trenutno imate :count stavki koje su zadužene vama koje niste prihvatili ili odbili. Molim vas kliknite na vezu ispod da bi ste potvrdili vašu odluku.',
    'license_expiring_alert' => 'Postoji :count licenci koja/e ističe u narednih treshold dana.|Postoje :count licencei koje ističu u narednih :treshold dana.',
    'link_to_update_password' => 'Kliknite na sledeću vezu kako biste obnovili svoju :web lozinku:',
    'login' => 'Prijava',
    'login_first_admin' => 'Prijavite se u vašu novu Snipe-IT instalaciju koristeći kredencijale ispod:',
    'low_inventory_alert' => 'Postoji :count artikla ispod minimalne zalihe ili će uskoro biti nizak. |Postoje :count artikla koji su ispod minimalne zalihe ili će uskoro biti.',
    'min_QTY' => 'Min Kol',
    'name' => 'Naziv',
    'new_item_checked' => 'Nova stavka je proverena pod vašim imenom, detalji su u nastavku.',
    'new_item_checked_with_acceptance' => 'Nova stavka je zadužena na vaše ime što zahteva prihvatanje. Detalji su u nastavku.',
    'recent_item_checked' => 'Stavka je nedavno zadužena na vaše ime što zahteva prihvatanje. Detalji su u nastavku.',
    'notes' => 'Zabeleške',
    'password' => 'Lozinka',
    'password_reset' => 'Ponovno postavljanje lozinke',
    'read_the_terms' => 'Pročitajte uslove upotrebe u nastavku.',
    'read_the_terms_and_click' => 'Molim vas pročitajte uslove ispod, i kliknite na vezu na dnu da bi ste potvrdili da ste ih pročitali i da se slažete sa uslovima korišćenja, i da ste primili imovinu.',
    'requested' => 'Tražena',
    'reset_link' => 'Link za resetovanje lozinke',
    'reset_password' => 'Kliknite ovde da biste poništili lozinku:',
    'rights_reserved' => 'Sva prava zadržana.',
    'serial' => 'Serijski broj',
    'snipe_webhook_test' => 'Provera Snipe-IT integracije',
    'snipe_webhook_summary' => 'Rezultat provere Snipe-IT integracije',
    'supplier' => 'Dobavljač',
    'tag' => 'Oznaka',
    'test_email' => 'Isprobajte e-poštu od Snipe-IT',
    'test_mail_text' => 'This is a test from the Snipe-IT Asset Management System. If you got this, mail is working :)',
    'the_following_item' => 'The following item has been checked in: ',
    'to_reset' => 'Da biste resetovali svoju :web lozinku, ispunite ovaj obrazac:',
    'type' => 'Tip',
    'upcoming-audits' => 'Ima :count imovina kojoj je vreme za popis za :threshold dana.|Ima :count imovine kojoj je vreme za popis za :threshold dana.',
    'user' => 'Korisnik',
    'username' => 'Korisničko ime',
    'unaccepted_asset_reminder' => 'Podsetnik: Imate neprihvaćevenu imovinu.',
    'welcome' => 'Dobrodošli :name',
    'welcome_to' => 'Dobrodošli na :web!',
    'your_assets' => 'Pregledaj svoju imovinu',
    'your_credentials' => 'Vaši Snipe-IT kredencijali',
    'mail_sent' => 'E-poruka je uspešno poslata!',
];
